@@ -854,6 +854,57 @@ class TestNetworkElement(unittest.TestCase):
 
         self.assertEqual(ne.snmp_ne.http_credentials, [HttpCredentials('user', 'pass', [12345, 80], None), HttpCredentials('user', 'pass', [], "router")])
 
+    def test_http_credentials_7(self):
+        """Test that OLT credentials can be configured."""
+        cfg = {
+            'http_port': [12345, 80],
+            'credentials': [{'username': 'user', 'password': 'pass', 'role': 'ap'}],
+            'olt_username': 'olt_user',
+            'olt_password': 'olt_pass',
+        }
+        # create a new registry object to pick up the config
+        self._await(self.reg.close())
+        self.reg = NetworkElementRegistry(self.ctx, cfg)
+        self.reg.ne_type = 'ap'
+
+        ne = self._await(self.reg.set('TestNE', {'name': 'Test Element', 'site': 'My Site'}))
+
+        self.assertEqual(ne.snmp_ne.http_credentials, [HttpCredentials('user', 'pass', [12345, 80], 'ap'), HttpCredentials('olt_user', 'olt_pass', [], 'olt')])
+
+    def test_http_credentials_8(self):
+        """Test that OLT credentials will not be configured when (username, password, role) exists."""
+        cfg = {
+            'http_port': [12345, 80],
+            'credentials': [{'username': 'user', 'password': 'pass', 'role': 'olt'}],
+            'olt_username': 'user',
+            'olt_password': 'pass',
+        }
+        # create a new registry object to pick up the config
+        self._await(self.reg.close())
+        self.reg = NetworkElementRegistry(self.ctx, cfg)
+        self.reg.ne_type = 'ap'
+
+        ne = self._await(self.reg.set('TestNE', {'name': 'Test Element', 'site': 'My Site'}))
+
+        self.assertEqual(ne.snmp_ne.http_credentials, [HttpCredentials('user', 'pass', [12345, 80], 'olt')])
+
+    def test_http_credentials_9(self):
+        """Test that OLT credentials will be configured when username and password pair exists, but the role does not match. This allows duplicate credentials where roles are configured differently."""
+        cfg = {
+            'http_port': [12345, 80],
+            'credentials': [{'username': 'user', 'password': 'pass'}],
+            'olt_username': 'user',
+            'olt_password': 'pass',
+        }
+        # create a new registry object to pick up the config
+        self._await(self.reg.close())
+        self.reg = NetworkElementRegistry(self.ctx, cfg)
+        self.reg.ne_type = 'ap'
+
+        ne = self._await(self.reg.set('TestNE', {'name': 'Test Element', 'site': 'My Site'}))
+
+        self.assertEqual(ne.snmp_ne.http_credentials, [HttpCredentials('user', 'pass', [12345, 80], None), HttpCredentials('user', 'pass', [], "olt")])
+
     def test_send_update_1(self):
         """Verify that send_update sends network_element_update_msg when matching elem_discovery
             reference is found."""
